# PyMajic: Crafting Python Projects, One Command at a Time!

PyMajic is a Python package that simplifies working with Django projects by providing convenient commands for environment management, custom commands, and more.

## Installation

```bash
pip install pymajic
```

## Usage

### Store Data

To store environment and project directory information:

```bash
pymajic store data
```

### Run Custom Command(In Dev Mode)

To run a custom Django management command:

```bash
pymajic run command <your_custom_command>
```

### Django Shell Access

To open a Django shell session:

```bash
pymajic shell
```

## Contributing

Contributions are welcome! If you have any ideas, bug reports, or feature requests, please open an issue or submit a pull request.

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.
